//+++
//+++ compile sample code and run as
//+++    ./cosmosMacGfort < param > out 2> err
//+++ ('MacGfort' depends on your system.)
//+++ out file contains information of each primary particle
//+++ plot primary spectrum by typing
//+++     root primary_analysis.cpp
//+++

const double EMIN = 0.0;  //+++ GeV +++
const double EMAX = 100.0;
const int NEBIN = 200;

void primary_analysis() {
    ifstream ifile("./out");
    int code, subcode, charge;
    double energy, coszenith;
    string buf;
    
    TH1F *hr1_proton = new TH1F( "hr1_proton", "", NEBIN, EMIN, EMAX);
    TH1F *hr1_Helium = new TH1F( "hr1_Helium", "", NEBIN, EMIN, EMAX);
    TH1F *hr1_CNO    = new TH1F( "hr1_CNO",    "", NEBIN, EMIN, EMAX);
    
    hr1_proton->SetLineColor( kBlack);
    hr1_Helium->SetLineColor( kRed);
    hr1_CNO->SetLineColor( kGreen+2);

    while (1) {
        ifile >> buf;
        if ( ifile.eof() ) break;
        if ( buf != "PRIM" ) continue;
        ifile >> code >> subcode >> charge >> energy >> coszenith;
 
        if ( code==6 && charge==1 ) hr1_proton->Fill(energy);
        if ( code==9 && charge==2 ) hr1_Helium->Fill(energy/4.0);
        if ( code==9 && charge==7 ) hr1_CNO->Fill(energy/14.0);
    }

    TCanvas *c1 = new TCanvas("c1", "", 50, 50, 800, 800);
    TLegend *leg = new TLegend( 0.6, 0.7, 0.88, 0.88);
    gStyle->SetOptStat(0);
    c1->cd();
    gPad->SetLogx();
    gPad->SetLogy();
    
    hr1_proton->SetXTitle("Energy/nucleon (GeV/n)");
    hr1_proton->SetYTitle("dN/dE");
    hr1_proton->Draw();
    hr1_Helium->Draw("same");
    hr1_CNO->Draw("same");
    
    leg->AddEntry( hr1_proton, "proton", "l");
    leg->AddEntry( hr1_Helium, "Helium", "l");
    leg->AddEntry( hr1_CNO, "CNO", "l");
    leg->Draw();
}
